Name:          libiio
Version:       0.15
Release:       1%{?dist}
Summary:       Library for Industrial IO
License:       LGPLv2
URL:           https://analogdevicesinc.github.io/libiio/
Source0:       https://github.com/analogdevicesinc/libiio/archive/v%{version}.tar.gz

BuildRequires: bison
BuildRequires: cmake
BuildRequires: flex
BuildRequires: gcc
BuildRequires: libserialport-devel
BuildRequires: libxml2-devel
BuildRequires: python3-devel
BuildRequires: python3-setuptools
BuildRequires: doxygen

%description
Library for interfacing with Linux IIO devices

libiio is used to interface to Linux Industrial Input/Output (IIO) Subsystem.
The Linux IIO subsystem is intended to provide support for devices that in some 
sense are analog to digital or digital to analog converters (ADCs, DACs). This 
includes, but is not limited to ADCs, Accelerometers, Gyros, IMUs, Capacitance 
to Digital Converters (CDCs), Pressure Sensors, Color, Light and Proximity 
Sensors, Temperature Sensors, Magnetometers, DACs, DDS (Direct Digital 
Synthesis), PLLs (Phase Locked Loops), Variable/Programmable Gain Amplifiers 
(VGA, PGA), and RF transceivers.

%package utils
Summary: Utilities for Industrial IO
Requires: %{name}%{?_isa} = %{version}-%{release}

%description utils
Utilities for accessing IIO using libiio

%package devel
Summary: Development package for %{name}
Requires: %{name}%{?_isa} = %{version}-%{release}

%description devel
Files for development with %{name}.

%package doc
Summary: Development documentation for %{name}
Requires: %{name}%{?_isa} = %{version}-%{release}

%description doc
Documentation for development with %{name}.

%package -n python3-iio
Summary: Python 3 bindings for Industrial IO (libiio)
Requires: %{name}%{?_isa} = %{version}-%{release}

%description -n python3-iio
Python 3 bindings for Industrial IO

%prep
%setup -q
sed -i 's/${LIBIIO_VERSION_MAJOR}-doc//' CMakeLists.txt

%build
if [ "%{_libdir}" = "%{_prefix}/lib64" ]; then
  %cmake -DUSE_LIB64:BOOL=ON .
else
  %cmake -DUSE_LIB64:BOOL=OFF .
fi

make %{?_smp_mflags} V=1

%install
make install DESTDIR=%{buildroot} INSTALL='install -p'

#Remove libtool archives.
find %{buildroot} -name '*.la' -delete

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%files
%license COPYING.txt
%{_libdir}/%{name}.so.*

%files utils
%{_bindir}/iio_*
%{_sbindir}/iiod

%files devel
%{_includedir}/iio.h
%{_libdir}/pkgconfig/%{name}.pc
%{_libdir}/%{name}.so

%files doc
%doc %{_docdir}/%{name}

%files -n python3-iio
%{python3_sitelib}/__pycache__/iio*
%{python3_sitelib}/iio*
%{python3_sitelib}/libiio*

%changelog
* Wed May 23 2018 Peter Robinson <pbrobinson@fedoraproject.org> 0.15-1
- Update to 0.15

* Wed Feb 07 2018 Fedora Release Engineering <releng@fedoraproject.org> - 0.14-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Mon Jan 29 2018 Peter Robinson <pbrobinson@fedoraproject.org> 0.14-1
- Update to 0.14

* Fri Dec 22 2017 Peter Robinson <pbrobinson@fedoraproject.org> 0.12-1
- Update to 0.12

* Wed Oct 25 2017 Peter Robinson <pbrobinson@fedoraproject.org> 0.11-1
- Update to 0.11

* Wed Aug 16 2017 Peter Robinson <pbrobinson@fedoraproject.org> 0.10-1
- Update to 0.10
- Review updates

* Wed Feb 22 2017 Peter Robinson <pbrobinson@fedoraproject.org> 0.9-1
- Initial package
